@@ -24,11 +24,17 @@ def cli():
             os.system('clear')
             for i in range(len(ecses)):
                 print(''.join([str(i+1), ':', ecses[i].__str__()]))
-            index = int(input('请选择ECS序号:'))
-            sship = ecses[int(index)].ip
+            while True:
+                try:
+                    index = int(input('请选择ECS序号:'))
+                    break
+                except IndexError:
+                    pass
+            cur_ecs=ecses[index-1]
+            sship = cur_ecs.ip
             # sship = '127.0.0.1'
-            print('ecs',':',ecses[i].__str__())
-            os.system('ssh root@' + sship)
+            print('ecs',':',cur_ecs.__str__())
+            os.system('ssh ' + sship)
         except SyntaxError as e:
             pass
 
